package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(+``````````0```````
M`*%H``````!``#@`"`!``!8`%0````8````$`````````$``````````0```
M``````!``````````<`````````!P``````````(`````P````0````````"
M``````````(``````````@``````````&``````````8``````````$````!
M````!0```````````````````````````````````````)@H````````F"@`
M```````0``````$````&````````F\@```````"KR````````*O(````````
M!+@````````%$````````!```````@````8```````";V````````*O8````
M````J]@````````!X`````````'@``````````AD=.50````!````````)'D
M````````D>0```````"1Y`````````#<`````````-P`````````!&1TY5$`
M```&````````````````````````````````````````````````````````
M```````09'3E4@````0```````";R````````*O(````````J\@````````$
M.`````````0X``````````$O;&EB+VQD+6UU<VPM<S,Y,'@N<V\N,0`````1
M````1`````0````(@`1`!0`0$""$`(:`!!``*`D$``D``"&""`($ND$8@(@`
M````````1````$@```!,````30```%,```!4````50````````!7````6```
M``````!9````6@```%P``````````'R:?VH.[]/J+4?>SA_?Q6^VF\4N#O&-
MN'S49-0.Y/\A'%AQV6!LH?HL/^7";XL!LH?7^D(!QD?B?)+CN](\PU5FS*]G
MTW`'B.S514/MVV(SS"6,%9N<J7\*`J?@4)X::TG[X*,`````````````````
M`````````````````````P``!P```````!>0```````````````!$@``````
M```````````````````````)$0````````````````````````````&O$0``
M``````````````````````````$X$@`````````````````````````````0
M$@````````````````````````````&($@``````````````````````````
M```8$@`````````````````````````````?$@``````````````````````
M``````&\$@````````````````````````````&4$@``````````````````
M```````````H(`````````````````````````````*^(0``````````````
M``````````````!`$@````````````````````````````!&$@``````````
M``````````````````)O$@````````````````````````````*N$@``````
M``````````````````````'7$@````````````````````````````!-$@``
M``````````````````````````)=$@````````````````````````````!4
M$@````````````````````````````!<$@``````````````````````````
M``)W$@````````````````````````````!D$@``````````````````````
M``````)&$@````````````````````````````!L$@``````````````````
M``````````!R$@````````````````````````````![(```````````````
M``````````````*G$@````````````````````````````"7$@``````````
M``````````````````"<$@````````````````````````````%5%@``````
M``````````````````````)D$@````````````````````````````($$@``
M``````````````````````````"C$@````````````````````````````'V
M$@````````````````````````````,"$@``````````````````````````
M``*]$0````````````````````````````(H$@``````````````````````
M``````*-$@````````````````````````````*_$0``````````````````
M``````````"J$@````````````````````````````%&$@``````````````
M``````````````"S(@````````````````````````````#"(```````````
M``````````````````#8$@````````````````````````````)^$@``````
M``````````````````````(4$@````````````````````````````#=(```
M``````````````````````````)1$@````````````````````````````#W
M$@````````````````````````````%Y$@``````````````````````````
M``#\$@````````````````````````````(V$@``````````````````````
M``````%H$@````````````````````````````$"$@``````````````````
M``````````$3$@````````````````````````````'2$@``````````````
M``````````````!M$@````````````````````````````'C$@``````````
M``````````````````(=$@````````````````````````````*&$@``````
M``````````````````````*?$@````````````````````````````$9$@``
M``````````````````````````'-$@````````````````````````````$@
M$@````````````````````````````$Q$@``````````````````````````
M``*:$@``"0```````!ZP`````````?H```&I$@``"@```````%#`````````
M``(```-$$@``"0```````#!@````````!7@```/P$@``"0```````#@8````
M`````&@```,A$@``"0```````"J(``````````8```.N$@``!P```````!>0
M``````````(```-G$@``"0```````#78`````````CP```/4$@``"0``````
M`"J0`````````@(```.?$```$P```````+"```````````````,R$@``"0``
M`````"^P`````````*P```-1$@``"0```````"CH`````````#@```-9$@``
M"0```````"\P`````````$X```-]$@``"0```````$Y``````````6@```.2
M$@``"0```````"R8`````````#0```/K$```$P```````+#8````````````
M``+G$@``"0```````"#@`````````#P```.T$@``"0```````"S0````````
M`2H```.($0``$@```````+!X``````````@```/-$```$@```````+"`````
M``````````.D$@``"0```````""P``````````````.K$@``"0```````$W0
M`````````&P```+P$@``"0```````"^``````````"P```,+$@``"0``````
M`"F(`````````/X```/A$@``"0```````$^H`````````18```/`$@``"0``
M`````"X``````````2X`;W!E;F1I<@!S=&1E<G(`<F5A;&QO8P!A8V-E<W,`
M<VYP<FEN=&8`7U]D97)E9VES=&5R7V9R86UE7VEN9F\`;'-E96L`9V5T<&ED
M`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``<W1R<F-H<@!L<W1A=`!C;&]S961I
M<@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!S=')S='(`<W1R
M8VAR`')E861L:6YK`%]?8WAA7V9I;F%L:7IE`%]?<F5G:7-T97)?9G)A;65?
M:6YF;P!E>&ET`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`<F5A9`!R;61I
M<@!?7V5R<FYO7VQO8V%T:6]N`&UK9&ER`&UE;6-P>0!?7W-T86-K7V-H:U]F
M86EL`&=E='5I9`!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!,7V-U
M<G)E;G1?8V]N=&5X=`!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T
M`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%]F:6YI`%!,7V1O
M7W5N9'5M<`!097)L7VYE=UA37V9L86=S`'!E<FQ?9G)E90!097)L7VUG7W-E
M=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E
M=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?
M1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L
M7V%L;&]C`')E861D:7(`<W1R8W!Y`&9P<FEN=&8`<W1R=&]K`%]?;&EB8U]S
M=&%R=%]M86EN`'-P<FEN=&8`<W1R9'5P`'!T:')E861?871F;W)K`%]?96YV
M:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S;"US,SDP>"YS;RXQ`%]S=&%R=%]C
M`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C=7)R96YT7V5X96-?
M<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S971U<%]L:6)P871H`'!A<E]M
M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!
M4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L`'!A<E]B87-E;F%M90!?7V)S
M<U]S=&%R=`!S:&%?:6YI=`!P87)?9&ER;F%M90!P87)?:6YI=%]E;G8`7V5D
M871A`'!A<E]F:6YD<')O9P!S:&%?9FEN86P`7V5N9`!P87)?8VQE86YU<``O
M=7-R+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]210````````````````"KR```
M```````,````````(?@```````"KT``````````,````````(9````````"O
MB``````````,````````'K````````"OH``````````,````````4,``````
M``"ON``````````,````````%Y````````"P```````````,````````L```
M``````"P&``````````,````````4Z8```````"P(``````````,````````
M4-P```````"P,``````````,````````4<@```````"P.``````````,````
M````4<P```````"P0``````````,````````4YH```````"P2``````````,
M````````42X```````"P4``````````,````````4Z(```````"P8```````
M```,````````4XH```````"P:``````````,````````4Y````````"P>```
M```````,````````4ZP```````"OD`````,````*``````````````````"O
MF`````0````*``````````````````"OJ`````P````*````````````````
M``"OL````!P````*``````````````````"OP````"`````X````````````
M``````"OR````"D````*``````````````````"OT````"P````*````````
M``````````"OV````"T````*``````````````````"OX````#$````*````
M``````````````"OZ````#8````*``````````````````"O\````#<````*
M``````````````````"O^````#P````*``````````````````"MT`````(`
M```+``````````````````"MV`````4````+``````````````````"MX```
M``8````+``````````````````"MZ`````<````+``````````````````"M
M\`````@````+``````````````````"M^`````D````+````````````````
M``"N``````H````+``````````````````"N"`````L````+````````````
M``````"N$`````P````+``````````````````"N&`````X````+````````
M``````````"N(`````\````+``````````````````"N*````!`````+````
M``````````````"N,````!$````+``````````````````"N.````!(````+
M``````````````````"N0````!,````+``````````````````"N2````!0`
M```+``````````````````"N4````!4````+``````````````````"N6```
M`!8````+``````````````````"N8````!<````+``````````````````"N
M:````!@````+``````````````````"N<````!D````+````````````````
M``"N>````!H````+``````````````````"N@````!L````+````````````
M``````"NB````!T````+``````````````````"ND````!X````+````````
M``````````"NF````!\````+``````````````````"NH````"$````+````
M``````````````"NJ````"(````+``````````````````"NL````",````+
M``````````````````"NN````"0````+``````````````````"NP````"4`
M```+``````````````````"NR````"<````+``````````````````"NT```
M`"@````+``````````````````"NV````"H````+``````````````````"N
MX````"L````+``````````````````"NZ````"P````+````````````````
M``"N\````"T````+``````````````````"N^````"X````+````````````
M``````"O`````"\````+``````````````````"O"````#`````+````````
M``````````"O$````#(````+``````````````````"O&````#,````+````
M``````````````"O(````#0````+``````````````````"O*````#4````+
M``````````````````"O,````#@````+``````````````````"O.````#D`
M```+``````````````````"O0````#H````+``````````````````"O2```
M`#L````+``````````````````"O4````#T````+``````````````````"O
M6````#X````+``````````````````"O8````#\````+````````````````
M``"O:````$`````+``````````````````"O<````$$````+````````````
M``````"O>````$(````+``````````````````"O@````$,````+````````
M``#K[_!P`"2Y!``/I_O_8.,`\```).OO\1``!`?^XQ#P.``DP!```$L#T@?P
M,!`(XQ`0$``$!_$'``<`!P#`$```2P+C$!````0'\0T0XQ`0#``4P/3____E
M`````,`0``!*]N,0$```!`?Q#1#C$!`,`!3`]/___]4````8P!```$KJXQ`0
M```$!_$-$.,0$`P`%,#T____Q0```##`$```2M[C$!````0'\0T0XQ`0#``4
MP/3___^U````2,`0``!*TN,0$```!`?Q#1#C$!`,`!3`]/___Z4```!@P!``
M`$K&XQ`0```$!_$-$.,0$`P`%,#T____E0```'C`$```2KKC$!````0'\0T0
MXQ`0#``4P/3___^%````D,`0``!*KN,0$```!`?Q#1#C$!`,`!3`]/___W4`
M``"HP!```$JBXQ`0```$!_$-$.,0$`P`%,#T____90```,#`$```2I;C$!``
M``0'\0T0XQ`0#``4P/3___]5````V,`0``!*BN,0$```!`?Q#1#C$!`,`!3`
M]/___T4```#PP!```$I^XQ`0```$!_$-$.,0$`P`%,#T____-0```0C`$```
M2G+C$!````0'\0T0XQ`0#``4P/3___\E```!(,`0``!*9N,0$```!`?Q#1#C
M$!`,`!3`]/___Q4```$XP!```$I:XQ`0```$!_$-$.,0$`P`%,#T____!0``
M`5#`$```2D[C$!````0'\0T0XQ`0#``4P/3___[U```!:,`0``!*0N,0$```
M!`?Q#1#C$!`,`!3`]/___N4```&`P!```$HVXQ`0```$!_$-$.,0$`P`%,#T
M___^U0```9C`$```2BKC$!````0'\0T0XQ`0#``4P/3___[%```!L,`0``!*
M'N,0$```!`?Q#1#C$!`,`!3`]/___K4```'(P!```$H2XQ`0```$!_$-$.,0
M$`P`%,#T___^I0```>#`$```2@;C$!````0'\0T0XQ`0#``4P/3___Z5```!
M^,`0``!)^N,0$```!`?Q#1#C$!`,`!3`]/___H4```(0P!```$GNXQ`0```$
M!_$-$.,0$`P`%,#T___^=0```BC`$```2>+C$!````0'\0T0XQ`0#``4P/3_
M__YE```"0,`0``!)UN,0$```!`?Q#1#C$!`,`!3`]/___E4```)8P!```$G*
MXQ`0```$!_$-$.,0$`P`%,#T___^10```G#`$```2;[C$!````0'\0T0XQ`0
M#``4P/3___XU```"B,`0``!)LN,0$```!`?Q#1#C$!`,`!3`]/___B4```*@
MP!```$FFXQ`0```$!_$-$.,0$`P`%,#T___^%0```KC`$```29KC$!````0'
M\0T0XQ`0#``4P/3___X%```"T,`0``!)CN,0$```!`?Q#1#C$!`,`!3`]/__
M_?4```+HP!```$F"XQ`0```$!_$-$.,0$`P`%,#T___]Y0```P#`$```27;C
M$!````0'\0T0XQ`0#``4P/3___W5```#&,`0``!):N,0$```!`?Q#1#C$!`,
M`!3`]/___<4```,PP!```$E>XQ`0```$!_$-$.,0$`P`%,#T___]M0```TC`
M$```25+C$!````0'\0T0XQ`0#``4P/3___VE```#8,`0``!)1N,0$```!`?Q
M#1#C$!`,`!3`]/___94```-XP!```$DZXQ`0```$!_$-$.,0$`P`%,#T___]
MA0```Y#`$```22[C$!````0'\0T0XQ`0#``4P/3___UU```#J,`0``!)(N,0
M$```!`?Q#1#C$!`,`!3`]/___64```/`P!```$D6XQ`0```$!_$-$.,0$`P`
M%,#T___]50```]C`$```20KC$!````0'\0T0XQ`0#``4P/3___U%```#\,`0
M``!(_N,0$```!`?Q#1#C$!`,`!3`]/___34```0(P!```$CRXQ`0```$!_$-
M$.,0$`P`%,#T___])0``!"#`$```2.;C$!````0'\0T0XQ`0#``4P/3___T5
M```$.,`0``!(VN,0$```!`?Q#1#C$!`,`!3`]/___04```10P!```$C.XQ`0
M```$!_$-$.,0$`P`%,#T___\]0``!&C`$```2,+C$!````0'\0T0XQ`0#``4
MP/3___SE```$@,`0``!(MN,0$```!`?Q#1#C$!`,`!3`]/___-4```28P!``
M`$BJXQ`0```$!_$-$.,0$`P`%,#T___\Q0``!+#`$```2)[C$!````0'\0T0
MXQ`0#``4P/3___RU```$R,`0``!(DN,0$```!`?Q#1#C$!`,`!3`]/___*4`
M``3@P!```$B&XQ`0```$!_$-$.,0$`P`%,#T___\E0``!/C`$```2'KC$!``
M``0'\0T0XQ`0#``4P/3___R%```%$`````#K;_`P`"3C\/](_W'C,/"H`"3C
M0/"@`"10(/"T04#PH$$P\*A!(/"TLD\`L,#E___^F,1(``!(B\0H``!(A+D$
M`#3`Y?___2W$&```2%#KNP`@``V5`!``LD\`L:=T`![`Y?___?[$*P``2-WL
M)@`(`'RG*0`!P.7___ZCP.7___[PP!```$A'XQ`0```$XQ&P```$D@`:)\`0
M``!(/.,0$```!.,1L```!%@@\+26`Q1Z[+(``P#8IRH`!+D4`"+K(@`#``W`
MY?___JOC0/"H``3C$$````3C$"```"3`$```&?KC$"`(`"3$&```2&_C$"`0
M`"3`$```&?#C$"`8`"2Y!`!2Q"L``$B%IQ@``>,@\+0`$KGRT"&G.0``[!,`
M!`#8ISL``;D4`!'K$0`#``VY"``5IR8`5[D4`$OE2!````"G:0``P#````24
MQ"@``$AIP.7___TD&++L)@`*`'[$*```2%_`Y?___DH8LL0H``!(6,#E___]
MP\`@```8I\#E```!6^PF`!\`?,`0``!(1>,0$````J=T``O`(```&&[`Y0``
M`4K$*P``2#?`$```2#3C(!````*GA``%P.4```O4Q"@``$@MP.7___[HP.7_
M__NUN10`*^MO\.@`!`?^ZZ,``P`-XPI````$XP`0```DI_3_E`<'!P<'![D$
M`"_`,````!+C,#```!BG^_]@IPD``.,`\```),#T````"0<'!P<``(L`!P<'
M!^MO\#``)$%`(`CC\/]8_W'$:```1UCE2/"@``#$6```1U[C,"`$`!3$*```
M1T#`Y?___5_K;_#8``0'_@<'!P?`$```1[#`(```1ZWL$@`*@&3$&```1S_L
M&``$`'P'\0?^!P<'!P<'P"```$><P!```$>9N0D`$NLA``,`"NLQ`#\`#+D(
M`#+K,P`!``KL.``-`'S$&```1S;L&``'`'S`(```1X`'\0?^!P<'!P<'Z[_P
M6``DP+```$=UX_#_8/]QE0"P`*=T`"/`$```1Q/C$!````*GA``(Q"@``$<C
MP.7___TVP.7___^MP!```$;NXQ`0```"IX0`",`@```X<L#E___[=9(!L`#K
MO_#X``0'_@<'!P?`$```1O#C$!````*GA``7Z^_P<``DP#```$<]X_#_8/]Q
MP"```#A3P.7___T6Z^_Q$``$P/3___^.P/3___^+ZV_P,``DX_#_8/]Q["@`
M30!\Q!@``$:_XZ`0```"IX0`1+D$`&.Y!`""N00`0N,00```E.P6`"X`?AM(
MN00`>KD4`)3CL'````*GA``=N00`2;D$`#BY!``KP.7___NM["8`'P!^01FP
M`)4]$`"G=``8N>F@IT&YL`'KJ@`#``I0H&``N00`*^MO\-``!`?^[!C_U3U^
M04!``:?T_\I!<'`(I_3_T:>Y``"G]/_M!P?KO_!8`"3C\/]0_W&R3P"P03#P
MI.N[`"``#;)/`+'2!_"HL"C`Y?___Y;5!_"HL"BGA``%P.7___VHZ[_Q"``$
M!_X'!P<'!P?KG_!(`"3C\/]0_W&R3P"@ZZH`(``-LD\`H;D$`++2!_"HH"A!
MD/"DN00`.;D$`"O`Y?___VSL)@`+`'S5!_"HH"BGA``>P.7___U[XQ#PI``4
MQ"@``$8CZQ$``P`-XQ`@```(XR`0"``$XR`0```D["C_W`!\01`0"*?T__7K
MG_#X``0'_@<'ZZ_P4``DX_#^R/]QLD\`L+D$`*+KNP`@``U!,/"@LD\`L=('
M\3"P*,#E___[1NPF`"D`?A@2ISA``%@@\+C`*P``\`#L(P`(@':E/Z``[",`
M#V!VISD``KD$`"K`Y?__^AP0$J<:__^($``?U0?Q,+`HN10`(:>$``G`Y?__
M_1VG&```I_3_].NO\8@`!`?^ZW_P.``DX_#^R/]QLD\`@.N(`"``#;)/`('2
M!_$P@"CL*``1`'RY!`"BE0`@`*>$``K`Y?__^:FY!`"2["8`:P!\U0?Q,(`H
MIX0`@L#E___\[$&PL!/`$```%A^G"```N00`*[)=`!*G%/_^IX0`4\`0```6
M$[D$`"NR70`2IQ3__J>$`$BY!``[N00`*J<9``"R7@`2IQ3__KD)`!JG*0``
MLEX`(Z<4__ZY"0`K&B&G*@`"N10`(L#E___Z5L`P```5[KD$`'*Y!`!;N00`
M2L#E___\>D$P\*"Y!``GP.7___Q#["@`+?]^6!#PN*<H0`#`&P``\`#L$@`C
M8':Y!``GP.7___]_N00`)\#E___\'+D$`"G`Y?__^>>Y!`"R[";_F0!\N00`
M*<#E___ZC;D$`"K`Y?__^]BG]/^$N00`)\#E___Z`:?T_^#K?_%P``0'_@<'
M!P?K;_`P`"3C\/]0[W'C$/"H$'&Y!`""LD\`D*=)``+KF0`@``VG.0``LD\`
MD=('$`"0*,#E___YC>RR__\`V>P;,(``5>RZ``P`?*<;___`(?__``"Y@0`2
MIQL``;D)`+&Y!`"KPJH``0``ZZH`$``,IZL``<*\__\``*<9``&YXE"A07#P
MH,!@``!$\:>G``:G*?__I_0`+J=)``"Y!``[N00`*,#E___Y5,!!``$`"+D$
M`#>Y!``HP.7___M*N10`(NPL``D'?>,B?_C_<>PG``B@9<*T``$``*?T_]G5
M!V``(`"G=``1N0D`)[D(`"OC$/"H$''5!Q``D"BGA``*P.7___OFXR`O__]Q
MI_3_X>MO\.`0!`?^ZV_P,``DX_#_4/]QLD\`<.MW`"``#;)/`'&Y!`"BT@?P
MJ'`HN00`LY4],`"G=``$0;`P`:<(``"Y!``;IYD``$$P\*2R7@"1IQ3__KD$
M`"JY"0";P.7___V6["@`)@!\IP@``*<9``"Y!``RLEX`$Z<4__ZY"0`2[)$`
M8"!EIQD``.,QL```D$(Q(`"G&P`![#;_^0!\U0?PJ'`HIX0`Q,#E___[BL08
M``!$->-@$```!*<9``"Y!`"!IQL``>LA``,`#>,B;_C_`J=T__;L*``"`-C`
M$```1):Y%``BXQ`0```2ZR(``P`-IX0`>;D$`#*Y!``FP.7___@OQ!@``$0*
MXR`0```D["C_QP!\[!@``0#8Q"@``$/^N10`$>,@(```!.L1``,`#5"`\*1!
M$2``Y4@0````N00`&N,@$```E.PH``8`?NPF`&H]?KD)`!KL*0`"`-FY&``A
MXX#PI``4Q&@``$/7ZX@``P`-N00`V./08```",#E___XON,@T```).PH_XD`
M?.,08```!.,8$```!.,@H```D$(@$`!!H*`!N00`,<`K````_T$0$`&GA``%
M[";_\#U^DCTP`*<I``#C,K```)!",A``IRL``>PV__D`?*?T_U_`$```1!+E
M3!````'`Y?__^(:Y!`#2["C_4@!\N10`2+D$`#;K1``#``W`Y?__^(?$&```
M0X+CT!```"2G]/][01`0`:?T_X[K;_#@``0'_@<'!P?`$```0VRR3P`@XQ`0
M```$ZR(`(``-P%```#1ILD\`(<1(``!#<,`P```3[>,A(```!,#T___Z6>MO
M\#``),`0``!#3>/P_UC_<>.P$```!+)/`*#KJ@`@``VR3P"AXRN@```$P&``
M`!4:P.7____+N00`5N5(\*```,!````&.^,KH```!,`P```3R\#E___WC.MO
M\-@`!`?^!P<'!P<'ZV_P,``DX_#_4/UQXQ#PJ`)QLD\`<.MW`"``#;)/`''2
M!Q``<"C`Y?__]Z]!L/"FN00`4L!@```3K\!````3KJ<Y$`&Y!``KP.7___=.
M["8`$/]^I[D``.,0\*@"<=4'$`!P**>$`$?`Y?__^C[L(!``(''CH/"G`7&G
M21``N00`.KD$`"O`Y?__^.^Y!`"2["3_X@!^IRH``;D4`"+`Y?__]\.Y!`"R
M["C_U@!\N10`B>PJ``>@9;GH@!*Y84"A[+H`!\!EN>B`&KEA0+'LD!`!('*Y
M!`!(N00`.KD$`"O`Y?__^>)!&+``D@`0`*?T_[6Y!``KZV_PX`($!_X'!\#T
M____@`<'ZV_P,``DX_#^P/YQXQ#Q.`%QN00`LKD$`*.R3P"`P"```!,^ZX@`
M(``-LD\`@=('$`"`*,#E___\$J<Y`"^Y!`"2N00`*\#E___X.^PH`!8`?+D$
M`#O`(```$R?`Y?___>;C$/$X`7'5!Q``@"BGA`#$P.7___FUN00`*L!P```2
MZ$&@\3C`Y?__]\O`,```$Q-!T/"HP.7___ECN00`4NQ8_]D`?)4`4`"YXH!7
M[)@`#P!\IP@``+D$`!6Y!``ILET`$J<4__ZGA`"+N00`):<(``"G&0``LEX`
M$J<4__[C(!___W&YZ5`Q[%(`!B!E[%8`!?]\ISD``:<W`#BG"```N00`%:<I
M``"R7@`AIQ3__KD)`"6G&0``N00`.[)>`!.G%/_^N0D`&T$2$`&G*0__[!+_
MD"!EX[#PH``DP&```!*[P$```!,EISD0`+D$`"K`Y?__]D6G&!``IRH``>PA
M`!#`=Z?T``&5+R``IW3_R)(`(`#C("___W&G]/^_N00`/;D$`"K`Y?__^,KL
M)@`H`'Y8$/#`I2^``,`;``#P`.P2`!Y@=J<Y``&Y!``JP.7___8&["8`%`!^
MN00`.L`@```2<L#E___],;D$`"K`Y?__]R:Y!`"RI_3_1,`P```2:J<I``#`
MY?__^+JY!`!2I_3_5[D$`"OK;_%P`00'_@<'!P<'!^N_\%@`)*<Y`"_C\/]@
M_W&Y!`"RP.7___;`["@`!0!\0;`@`;D$`"OKO_#X``3`]/__]O,'!P<'ZZ_P
M4``DX_#_6/YQLD\`H.,0\*`!<>NJ`"``#;)/`*'2!Q``H"CL*``)`'RY!``R
ME0`@`*=T``WC$/"@`7'5!Q``H"BGA`!FP.7___BJIP@``*<9``"R7@`2IQ3_
M_J<I$`"Y"0`3IQL``>P2`%P@94&P\*"Y!``KP.7___9BN00`*Z<(``"G&0``
MLEX`$J<4__[C(!___W&YZ;`Q[+(`"R!EXQ#PJ`%QITD0!^P4``5@9*<Y``&G
M-P`BISD`+[D$`"O`Y?__]DWL*/^X`'SL*P`%P&62`"``N00`*\#E___V@.,0
M\*`!<=4'$`"@**=T_ZWKK_#X`00'_I4O(`"G=/_>D@`@`.,@+___<:?T_]7`
M(```$7[KK_#X`03`]/__]F"G*0``I_3_W@<'!P<'!^OO\'``),`@```1H./P
M_V#_<<#E___ZC\`@```1G,#E___ZB<`@```1FL#E___Z@\`@```1F<#E___Z
M?<`@```1E\#E___Z=\`@```1F<#E___Z<<`@```1:\#E___Z:\`@```1D\#E
M___Z9<`@```1DL#E___Z7\`@```1D<#E___Z6<`@```16,#E___Z4\`@```1
MBL#E___Z*>PH``L`?+D$`#+`(```$77`Y?___`;`(```$8+`Y?__^ABY!``R
M["@`"0!\P"```!&`P.7___OUP"```!&`P.7___H'N00`,NPH`!4`?,`@```1
M(,#E___[Y,`P```1@,`@```1-^OO\1``!,#T___[V,`@```1:\#E___YZKD$
M`#+L*/_L`'S`(```$3&G]/_C!P?K[_!P`"3`(```$2CC\/]@_W'`Y?__^=/L
M*``7`'R_(2``IX0`$L`G````,+F$`"*Y`P`B["(_OP%5N10`(NOO\1``!`?^
MIR@``*?T__@'!^OO\'``)./P_V#_<<#E___W@,#E___U_>PH``8`?.,@(```
M!.OO\1``!`?^!P<'!^MO\#``)+D$`++C\/]@_W'`(```$1S`Y?__^9&Y!``[
M["@`"0!\N00`8I4`(`"G=``+P"```!$+ZV_PT``$P/3___MEP.7___5\["8`
M+0!\IP@``+D$`!NR7@`AIQ3__KD$`#:G&0``LEX`$Z<4__ZY"0`6N0D`*T$B
M$`+`Y?__],#`,```$/:Y!`"BP%```!"#N00`2\#E___VX[D$`#JG]/_)ZV_P
MT``$!_X'!P<'ZV_P,``DX_#^*/]QLD\`@.N(`"``#;)/`('`$```/\?2!_'0
M@"C2#_"P$!#2!_#`$"#2+_#@$"C2#_#($%C2!_#8$&BY!`"2P"```!!!P.7_
M__D=["@`'`!\N00`LI4`(`"GA``5P.7___]UU0?QT(`HIX0`!<#E___VR[D$
M`"OK;_((``3`]/__]./`Y?___TJY!`"R["8`)0!\0:#PR.,@H````J=T``?`
ML```$'^G]``8P.7___CJ["8`!P!\IZL`"*?T_^Z5`"``IX3_^L#E___TOKD$
M`++L*/_S`'RG"```N00`&Z<I``"R7@`AIQ3__KD)`"OK(@`!``VG*P`!P.7_
M__0EN00`8KD$`*+C0+```)3L1@"8`'Y!H/#@X["@```"IX0`';D$`"O`Y?__
M^*VY!`"R["@`EP!\E0`@`*>$`)+`Y?__^0GL*`"-`'ZY!``KP.7___1[N00`
MLD&@\+#LM@`,`'SC<*````*GA`"2E0!P`*=T`'NG"```N00`&Z>I``"R7@"A
MIQ3__KD$`":G&0``LEX`$J<4__ZY"0`6N0D`JQJAIZH$!+D4`*JY!``JP.7_
M__/+XV#PH``DN00`<L`P```/^\!@```/]<!0```/B;D$`$O`Y?__]>BG.0'`
MN00`)\#E___UD>PF`%;_?L#E___U>UA@(`#L:`!.$7[$&```/I6Y%`!FN00`
M5^-`D```!,`P```/UN,@$```!,#E___U`Z>I``#5!_'0@"BG=/\@N00`*NMO
M\@@`!`?^N00`*KD4`$3`,```#['`Y?__]:Q!L+`!0:"@`J?T_U>GJP`(I_3_
M6[D$`"=!H*`(P.7___AQ["C_=P!^N00`)\#E___SX[D$`+*G]/]JI[D``*?T
M_W)!,/$0N00`)\#E___SM!C2["8`#0!^6!#Q**<H0`#`&P``\`#L$@`6@';$
M&```/C6Y!`!7XT"0```$P#````^6XR`0```$P.7___2EI_3_HEBP\2S`Y?__
M]9[LLO_H8'98$/$HIR@!P,`;```!_^P2_]Y@=KD$`"K`Y?__\QRY!`"BP"``
M``^<P.7___>RN00`,NPF`,,`?..PD```!*<(``"G&0``N00`*[)>`!*G%/_^
MN0D`&^P<`#X#?KD4`"'C,K_\_W'`(```#WVR70`CIQ3__J=T`"_L&``-!'ZG
M&O_[N10`$4$1L`"5+Q``IW0`(N,0D`@``J>$`!VG"```IRD``+D$`#&R7@`C
MIQ3__KD)`"'L+``/`WWC,A_\_W'`(```#U.R70`CIQ3__KGB@+'`Y?___8'L
M)@!]`'ZY!``KISD``,#E___S1;D$`++L*`!Q`'[`Y?__^*>Y!`"2["0`:0!\
MXS`O]O]QITD``+D$`"O`Y?__\CZG20`&03#QH;D$`"O`Y?__]#7`$```+JG5
M!1``\:&G=`!-ITD``.,PG\[_<;D$`"O`Y?__\B.G20`H06#QI[D$`"NY!``V
MP.7___08P!````]?D@#QS^,0\*``),!0```..;D$`$?`,```#O:Y!``JP.7_
M__23N00`)\#E___T3KD$`#K`(```#AC`Y?__^-RY!``JP.7___U3I_3^P.,@
MD```!,#E___ZN[D$`++L)O\[`'RG]/\UP#````YDP"````XIP.7___B_P.7_
M__'FP!````\=N00`8N,0\*``),!0```-][D$`$?`,```#KRY!``JP.7___11
MISD!P+D$`"K`Y?__\_KL)O^W_W[`Y?__\^18$"``IQX`$:=T_ZW`Y?__\;O`
M$```#O+C$/"H`"2GV@`!N10`';D$`&+C$/"@`"3`4```#<6Y!`!'P#````Z1
MN00`*L#E___T'Z?T_\[KC_!``"3`$```//&R3P"PXQ`0```$Z[L`(``-LD\`
ML>,1L```!./P_V#_<<`@```-L](`$+$0L,#E___V;.PH``L`?)4Q(`"G=``&
ME0`@`:>$``7`Y?__^^K`$```/,>G60`#XY`0```$ITD``<`P```.6>,IL```
M!,#E___R;;D$`*+L*``B`'SC$"`0``3`0```#DGC,!````3C*;````3`Y?__
M\GGC$*`0``3C,!````210#`-IX0`".,IL```!,#E___Q:<`0```\D*=9``/C
M@!````2G20`!P#````XFXRBP```$P.7___(VN00`HNPH`#<`?,`@```-,L#E
M___V";D$`$+L*``1`'SC$*`0``3C,!````3C*+````3`Y?__\CJG]``=P.7_
M__E#XQ"@$``$N00`DNPH`%,`?+D$`$+C,!````3C*+````3`Y?__\B*Y!``I
MP.7___,MP!```#Q$ITD``>.@$```!,`P```-W>.:L```!+D$`"G`Y?__\&K`
M0```#=VY!``RN00`*<#E___R`.,:L```!)(`$+'`(```#-?`Y?__];/$*P``
M/*#L)@`=`'S$*```/);`Y?___&/$*P``/)3L)@`1`'S`(```#;G`Y?__\'W$
M*```/(3C0"````2G]/^4ISD!P,0H```\?L#E___RS;D$`%+L$@`!`-CL'``5
M`7_L*``2$7[$&```/&G$2```/&KC,!````3`(```#:#`Y?__\%/KC_#@``0'
M_@<'!P?KK_!0`"3C\/]@_W&Y!`"RP.7___I4P.7___HUN00`HL#E___[?.PH
M`!T`?NRX`!H`?)4`L`"GA``5P#````SBN00`*L#E___Q2.RB``M@9+D$`"OK
MK_#P``3`]/__]>OKK_#P``0'_K)/`!#K$0`@``VR3P`1ZV_P,``DIUD`"./P
M_-#_<=('\R@0**>Y``!!$/"HN00`,>-+(#@`!.L$`"``#.,`,```),!*````
M`.-`,`@`)*>[``BG.P`0IU?_[:=)`$#C,!!H``3C,!!``(+C,!`0`(+C,!``
M`(+L4R"_(57L4R`^`5;C4!"``"2G&P`(IT?_Z>,0(!@`!.,0\*``).,0\*@`
M!,(:6H)YF>,0("``".,P(```!.-`(!``!.,`(`@`!.RS(+\E5>RS(#H%5KD(
M`+'C$/"@``2YYQ`4N8``$.,0\*``@N.0\+``!+D(`+'"FEJ">9GL>R"_`%7C
MD/"@``CLNSN_)57K$``"``SLMP`Z!5;L$``A'E;C4/#```3LT2"_`%7"6EJ"
M>9FYY]"DN8``H[F"`*2Y"`"IN0@`J^R*(+\`5>RJ.[\E5>RH`#H%5NNS``(`
M#..0\+@`!.RS`"$>5L*:6H)YF>QK(+\`5;F"`!NY"`"4N8``%[F"`!VY"`#5
MN0@`&>-0\,@`!+D(`!K"6EJ">9GKIP`"``SLIP`A'E:Y@@"ZN8``N+F"`+:Y
M"`"][)$@OP!5['H@OP!5N0@`9>P1.[\E5>-0\-``!.P9`#H%5L):6H)YF;D(
M`!OKN``"``SLN``A'E:Y@@"KN8``J;F"`*>Y"`"F[-$@OP!5[(L@OP!5N0@`
M=>P1.[\E5>-0\-@`!.P=`#H%5L):6H)YF;D(`!KKJ0`"``SLJ0`A'E:Y@@"Z
MN8``O;F"`+BY"`"W[&$@OP!5[)H@OP!5N0@`A>P1.[\E5>-0\.``!.P6`#H%
M5L):6H)YF;D(`!OKO0`"``SLO0`A'E:Y@@"KN8``IKF"`*FY"`"H['$@OP!5
M[-L@OP!5N0@`E>P1.[\E5>-0\.@`!.P7`#H%5L):6H)YF;D(`!KKI@`"``SL
MI@`A'E:Y@@"ZN8``M[F"`+VY"`"Y[($@OP!5[&H@OP!5N0@`U>P1.[\E5>-0
M\/``!.P8`#H%5L):6H)YF;D(`!OKMP`"``SLMP`A'E:Y@@"KN8``J+F"`*:Y
M"`"M[)$@OP!5['L@OP!5N0@`9>P1.[\E5>-0\/@`!.P9`#H%5L):6H)YF;D(
M`!KKJ``"``SLJ``A'E:Y@@"ZN8``N;F"`+>Y"`"V[-$@OP!5[(H@OP!5N0@`
M=>P1.[\E5>-0\0``!.P=`#H%5L):6H)YF;D(`!OKN0`"``SLN0`A'E:Y@@"K
MN8``K;F"`*BY"`"G[&$@OP!5[)L@OP!5N0@`A>P1.[\E5>-0\0@`!.P6`#H%
M5L):6H)YF;D(`!KKK0`"``SLK0`A'E:Y@@"ZN8``MKF"`+FY"`"X['$@OP!5
M[-H@OP!5N0@`E>P1.[\E5>-0\1``!.P7`#H%5L):6H)YF;D(`!OKM@`"``SL
MM@`A'E:Y@@"KN8``I[F"`*VY"`"I[($@OP!5[&L@OP!5N0@`U>P1.[\E5>-0
M\1@`!.P8`#H%5L):6H)YF;D(`!KKIP`"``SLIP`A'E:Y@@"ZN8``N+F"`+:Y
M"`"][)$@OP!5['H@OP!5N0@`9>P1.[\E5>-0\2``!.P9`#H%5L):6H)YF;D(
M`!OKN``"``SLN``A'E:Y@@"KN8``J;F"`*>Y"`"F[-$@OP!5[(L@OP!5N0@`
M=>P1.[\E5>-0\2@`!.P=`#H%5L):6H)YF;D(`!KKJ0`"``SLJ0`A'E:Y@@"Z
MN8``O;F"`+BY"`"W[&$@OP!5[)H@OP!5N0@`A>P1.[\E5>-0\3``!.P6`#H%
M5L):6H)YF;D(`!OKO0`"``SLO0`A'E:Y@@"KN8``IKF"`*FY"`"H['$@OP!5
M[-L@OP!5N0@`E>P1.[\E5>-0\3@`!.P7`#H%5L):6H)YF;D(`!KKI@`"``SL
MI@`A'E:Y@@"ZN8``M[F"`+VY"`#5N0@`N>R!(+\`5>QJ(+\`5>P1.[\E5>P8
M`#H%5KD(`!OKMP`"``SLMP`A'E:Y@@"KN8``J+F"`*:Y"`"M[-$[OR55[-$@
M.@56[)$@OP!5N0@`K>Q[(+\`5>O8``(`#.S8`"$>5KGGT!OCL/%```3"NEJ"
M>9FY"`"VN8``&>N)``(`#+F"`!?LB0`A'E:Y"``;N>>`G>RZ.[\E5;F"`)KL
MNB`Z!5:Y"``;X[#Q2``$PKINV>NAN0@`M^QZ(K\^5;D:`+GL>@(A'E;LD3N_
M)56YYW"H[)$@.@56N8(`H;D(`+GL82*_/E7CD/%0``3L80(A'E;"FF[9ZZ&Y
M&@"=N1H`FNRK.[\E5>RK(#H%5KD(`)KCH/%8``3"JF[9ZZ&YYV`7N8(`&[D:
M`*BY&@"A[!D[OR55[!D@.@56[(LBOSY5N0@`H>R+`B$>5KGG@!:Y@@`9X[#Q
M8``$PKINV>NAN1H`M^QY(K\^5;D:`+'L>0(A'E;L&CN_)56YYW"8[!H@.@56
MN8(`FKD(`+'C$/%H``3"&F[9ZZ&Y&@`6N1H`&>R;.[\E5>R;(#H%5KD(`!GL
MFB*_/E7LF@(A'E;CH/%P``3"JF[9ZZ&Y&@"HN>>0A[F"`(NY&@"H[($[OR55
M[($@.@56N0@`J.R+(K\^5>R+`B$>5N.P\7@`!,*Z;MGKH;D:`+>YYX!YN8(`
M<;D:`+?L>CN_)57L>B`Z!5:Y"`"W['$BOSY5['$"(1Y6XQ#Q@``$PAINV>NA
MN1H`&;GG<)BY@@":N1H`&>R;.[\E5>R;(#H%5KD(`!GLFB*_/E7LF@(A'E;C
MH/&(``3"JF[9ZZ&Y&@"HN>>0A[F"`(NY&@"H[($[OR55[($@.@56N0@`J.R+
M(K\^5>R+`B$>5N.P\9``!,*Z;MGKH;D:`+>YYX!YN8(`<;D:`+?L>CN_)57L
M>B`Z!5:Y"`"W['$BOSY5['$"(1Y6XQ#QF``$PAINV>NAN1H`&;GG<)BY@@":
MN1H`&>R;.[\E5>R;(#H%5KD(`!GLFB*_/E7LF@(A'E;CH/&@``3"JF[9ZZ&Y
M&@"HN>>0A[F"`(NY&@"H[($[OR55[($@.@56N0@`J.R+(K\^5>R+`B$>5N.P
M\:@`!,*Z;MGKH;D:`+>YYX!YN8(`<;D:`+?L>CN_)57L>B`Z!5:Y"`"W['$B
MOSY5['$"(1Y6XQ#QL``$PAINV>NAN1H`&;GG<)BY@@":N1H`&>R;.[\E5>R;
M(#H%5KD(`!GLFB*_/E7LF@(A'E;CH/&X``3"JF[9ZZ&Y&@"HN>>0A[F"`(NY
M&@"H[($[OR55[($@.@56N0@`J.R+(K\^5>R+`B$>5N.P\<``!,*Z;MGKH;D:
M`+>YYX!YN8(`<;D:`+?L>CN_)57L>B`Z!5:Y"`"W['$BOSY5['$"(1Y6XQ#Q
MR``$PAINV>NAN1H`&;GG<)BY@@":N1H`&>R;.[\E5>R;(#H%5NQJ(K\^5;D(
M`!GL:@(A'E:YYV"7N8(`F^.@\=``!,*J;MGKH;D:`*BY&@"I[)$[OR55[)$@
M.@56N0@`J>R;(K\^5>R;`B$>5KGGD+:Y@@"Q[(H@OP!5X]#QV``$PMINV>NA
MN1H`U[D:`-OLNCN_)57LN``Z!5:Y"`#;[+$BOSY5[+$"(1Y6XQ#QX``$PAIN
MV>NAN1H`%K/!``&YY[`9N8(`&K/-`*#L?2"_`%7LW3N_)56Y&@"A[-<`.@56
MZQ@``@`,N0@`K>P8`"$>5NQJ(+\`5>R!(+\`5>RJ.[\E5;GD@%OLI@`Z!5:Y
MYA#;N8``U[F!`-7C4/'H``3"6H\;O-RY&@!9N0@`U;D(`-KKIP`"``SLIP`A
M'E:YY(!ZN8$`&KF``!:Y@0`7XW#Q\``$PGJ/&[S<N1H`>^R=(+\`5;GH<+'L
MW3N_)57K%@`"``SLV0`Z!5;L%@`A'E:Y"`"][&$@OP!5['L@OP!5N>1@6NR[
M.[\E5>RW`#H%5KGF$-JY@`#9N8$`U>-0\?@`!,):CQN\W+D(`(6Y"`#8N0@`
MV^NY``(`#.RY`"$>5KGD8)NY@0`;N8``%[F!`!GCD/(```3"FH\;O-RY&@":
M[(T@OP!5N>B0H>S=.[\E5>L7``(`#.S8`#H%5NP7`"$>5KD(`*WL<2"_`%7L
MFB"_`%6YY'!;[*H[OR55[*D`.@56N>80V[F``-BY@0#5XU#R"``$PEJ/&[S<
MN0@`9;D(`-:Y"`#:ZZ@``@`,[*@`(1Y6N>1PBKF!`!JY@``9N8$`&..`\A``
M!,**CQN\W+D:`(OL;2"_`%6YZ("Q[-T[OR55[-8`.@56N0@`O>R+(+\`5>L9
M``(`#.P9`"$>5NR[.[\E5>R1(+\`5>RX`#H%5KGDD%JYYA#:N8``UKF!`-7C
M4/(8``3"6H\;O-RY"`!UN0@`U[D(`-OKM@`"``SLM@`A'E:YY)!KN8$`&[F`
M`!BY@0`6XV#R(``$PFJ/&[S<N1H`:NQ](+\`5;GH8*'LW3N_)57K&``"``SL
MUP`Z!5;L&``A'E:Y"`"M[($@OP!5[&H@OP!5N>2`6^RJ.[\E5>RF`#H%5KGF
M$-NY@`#7N8$`U>-0\B@`!,):CQN\W+D(`)6Y"`#9N0@`VNNG``(`#.RG`"$>
M5KGD@'JY@0`:N8``%KF!`!?C</(P``3">H\;O-RY&@![[)T@OP!5N>APL>S=
M.[\E5>L6``(`#.S9`#H%5NP6`"$>5KD(`+WL82"_`%7L>R"_`%6YY&!:[+L[
MOR55[+<`.@56N>80VKF``-FY@0#5XU#R.``$PEJ/&[S<N0@`A;D(`-BY"`#;
MZ[D``@`,[+D`(1Y6N>1@F[F!`!NY@``7N8$`&>.0\D``!,*:CQN\W+D:`)KL
MC2"_`%6YZ)"A[-T[OR55ZQ<``@`,[-@`.@56[!<`(1Y6N0@`K>QQ(+\`5>R:
M(+\`5;GD<%OLJCN_)57LJ0`Z!5:YYA#;N8``V+F!`-7C4/)(``3"6H\;O-RY
M"`!EN0@`UKD(`-KKJ``"``SLJ``A'E:YY'"*N8$`&KF``!FY@0`8[&T@OP!5
MXX#R4``$[-T[OR55PHJ/&[S<[-8`.@56N1H`B[GH@+'K&0`"``SL&0`A'E;L
MD2"_`%6YY)!:N0@`O;GF$-JY@`#6N8$`U>-0\E@`!,):CQN\W+D(`'6Y"`!]
M[(L@OP!5[+L[OR55[+@`.@56N0@`M^MV``(`#.S;(+\`5>QV`"$>5NR[.[\E
M5;GDD&?LO0`Z!5:Y@0`7N8``&+F!`!;C8/)@``3":H\;O-RY&@!JN0@`%KD(
M`!OKN``"``SLN``A'E;LBR"_`%6YY(!7N>:P9[F``&VY@0!EXU#R:``$PEJ/
M&[S<N0@`E;D(`);LH2"_`%7L$3N_)57L&@`Z!5:Y"``9ZYT``@`,[&$@OP!5
M[)T`(1Y6[!$[OR55N>2`V>P6`#H%5KF!`+FY@`"ZN8$`O>/0\G``!,+:CQN\
MW+D:`->Y"`"]N0@`L>L:``(`#.P:`"$>5NRA(+\`5;GDH%FYYA#9N8``UKF!
M`-7C4/)X``3"6H\;O-RY"`"%N0@`C>Q[(+\`5>S;.[\E5>S;(#H%5KGHT+CK
MA@`"``SLA@`A'E:YY*!HN8$`&+F``!>Y@0`6XV#R@``$PFJ/&[S<N1H`:>R;
M.[\E5>R;(#H%5KD(`!;K9P`"``RY"``9[&<`(1Y6XY#RB``$N>=@>,*:RF+!
MUKF"`'NY"`":[*$[OR55[*$@.@56N1H`E^Q[(K\^5;D(`)KL>P(A'E:YYW"F
MN8(`H>.P\I``!,*ZRF+!UKD:`+CL@2*_/E6Y&@"Z[($"(1Y6[*D[OR55N>>`
M%^RI(#H%5KF"`!FY"`"ZXZ#RF``$PJK*8L'6N1H`INQI(K\^5;D:`*'L:0(A
M'E;L&SN_)56YYV"8[!L@.@56N8(`F[D(`*'C$/*@``3"&LIBP=:Y&@`7N1H`
M&>R:.[\E5>R:(#H%5KD(`!GLFR*_/E7LFP(A'E;CL/*H``3"NLIBP=:Y&@"X
MN>>0AKF"`(JY&@"X[($[OR55[($@.@56N0@`N.R*(K\^5>R*`B$>5KGG@'FY
M@@!QXZ#RL``$PJK*8L'6N1H`IKD:`*?L>SN_)57L>R`Z!5:Y"`"G['$BOSY5
M['$"(1Y6XQ#RN``$PAK*8L'6N1H`&;GG<)BY@@";N1H`&>R:.[\E5>R:(#H%
M5KD(`!GLFR*_/E7LFP(A'E;CL/+```3"NLIBP=:Y&@"XN>>0A[F"`(JY&@"X
M[($[OR55[($@.@56N0@`N.R*(K\^5>R*`B$>5N.@\L@`!,*JRF+!UKD:`*>Y
MYX!YN8(`<;D:`*?L>SN_)57L>R`Z!5:Y"`"G['$BOSY5['$"(1Y6XQ#RT``$
MPAK*8L'6N1H`&;GG<)BY@@";N1H`&>R:.[\E5>R:(#H%5KD(`!GLFR*_/E7L
MFP(A'E;CL/+8``3"NLIBP=:Y&@"XN>>0A[F"`(JY&@"X[($[OR55[($@.@56
MN0@`N.R*(K\^5>R*`B$>5N.@\N``!,*JRF+!UKD:`*>YYX!YN8(`<;D:`*?L
M>SN_)57L>R`Z!5:Y"`"G['$BOSY5['$"(1Y6XQ#RZ``$PAK*8L'6N1H`&;GG
M<)BY@@";N1H`&>R:.[\E5>R:(#H%5KD(`!GLFR*_/E7LFP(A'E;CL/+P``3"
MNLIBP=:Y&@"XN>>0A[F"`(JY&@"X[($[OR55[($@.@56N0@`N.R*(K\^5>R*
M`B$>5N.@\O@`!,*JRF+!UKD:`*>YYX!YN8(`<;D:`*?L>SN_)57L>R`Z!5:Y
M"`"G['$BOSY5['$"(1Y6XQ#S```$PAK*8L'6N1H`&;GG<)BY@@";N1H`&>R:
M.[\E5>R:(#H%5KD(`!GLFR*_/E7LFP(A'E;CL/,(``3"NLIBP=:Y&@"XN>>0
MA[F"`(JY&@"X[($[OR55[($@.@56N0@`N.R*(K\^5>R*`B$>5N.@\Q``!+GG
M@&G"JLIBP=:Y@@!AN1H`I[D:`*:Y!`!Z[*L[OR55[*L@.@56N0@`>NRA(K\^
M5>RA`B$>5N,0\Q@`!,(:RF+!UKD:`!FYYZ"8N8(`F^QG(+\`5;D:`!GLESN_
M)57LE@`Z!5:Y"``9[)LBOSY5[)L"(1Y6X[#S(``$PKK*8L'6[-$@OP!5N0@`
M.^P1.[\E5;GGD+KL'0`Z!5:Y&@`XN8(`M[D:`#NY"``3P!H`````XQ`@```D
MXZ`@(``(N0@`T..0\*``",#:`````./0(`@`),":`````..0(!@`),"J````
M`..@("``).L6``(`#.P6`"$>5KD(`!3`&@````#C$"`0`"2R3P`0ZQ$`(``-
MLD\`$=4'\R@0**>$``7`Y?__Z%;K;_-@``0'_@<'Z^_P<``DIRD`@./P_V#_
M<<#E___EYL`Q9T4C`>,P(```),`_[\VKB>,P(`@`),`_F+K<_N,P(!``),`Q
M$#)4=N5(("@``.,P(!@`).5((#```,`_P]+A\.5,('@``.,P("``).OO\1``
M!`?^!P<'!^MO\#``).L4``,`#;D$`)*Y!`"CXR`@*``$N0@`$NPQ(+\`5>/P
M_V#_<;D$`+2Y,0`AI\0`!>L!D#``>N,PD"@`).L;`!T`#.,0D#``".,0D#``
M)$%PD#CC$)!X`!*GA``OIX@`0!N!&8NY!``GN?(PB[D8`"&Y%`!H["H`1J!E
MN>A@$KEA0*&Y!`!&N00`.L#E___GKA@86A"0>%`0D'CL%@`O0'ZY^8"+N0@`
MIKD4`+BY!``IP.7___3%ZXL`!@#>IXH``1*[IQ@``;GR4(%!8)!XIX8`(KDA
M`*>GQ``^N>BP%[EA0*&Y!`!+N00`.KD$`"?`Y?__YWQ0L)!XZV_PT``$!_ZY
MZ&`:["K_O\!EN6%`(:?T_[JY(0"G01"@0*?$``?LI@`*H&6G]``!IZ0`!>QQ
M__Q`9=(_<`"@`*>Z_\"Y!`"AN10`N[D$`"G`Y?__]'FG]/_`IZ3_R+GHL!JY
M84!QI_3_PNN/\$``)+D$`*+CD#`H``3C@#`P``3L*3J_/57L$@`!`-BY%``B
M02(P.)*`(`#C\/]@_W&Y%``AN00`LT%",#CL'`!9.'ZG*`!`IUD``+GY$!*Y
M!``DN18`,:=)``"H)```IQ3__KD$`"O`Y?__]#?7-[`XL#A"@+!S0I"P=^L8
M`!@`#$(0L'#K&``0``Q"$+!QZQ@`"``,0A"P<NL9`!@`#$(0L'3K&0`0``Q"
M$+!UZQD`"``,0A"P=KD$`"O`Y?__]`W2`Z``L`2Y!``KT@.@!+`,T@.@"+`4
MT@.@#+`<T@.@$+`DZX_PX``$P/3__^9\IR@`.*=9``"Y^1`2N00`)+D6`#&G
M20``J"0``*<4__ZG]/^R!P?K[_!P`"2Y!``/I_O_8.,`\```).OO\1``!`?^
M+@`N+@``)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R
M;F%L<SHZ4$%2.CI"3T]4``!E>&4`+W!R;V,O)6DO)7,`4$%27U1%35```%!!
M4E]04D]'3D%-10``.@`O`%!%4DPU3$E"``!015),3$E"`%!%4DPU3U!4``!0
M15),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`
M4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'``!005)?1TQ/
M0D%,7U1-4$1)4@!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,
M3T)!3%]#3$5!3@``,0!,1%],24)205)97U!!5$@`4UE35$5-```E,#)X``!P
M87(M```E<R5S)7,E<P``)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B
M9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@
M<F5T<GD@>6]U<B!O<&5R871I;VXI"@``4$%42```<&%R;```+G!A<@``)7,E
M<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P``
M&`!P97)L```P`%!!4CHZ4&%C:V5R.CI615)324].```Q+C`U-P!5;F%B;&4@
M=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``)7,Z(&-R96%T:6]N(&]F('!R
M:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI
M"@``+64``"TM``!54T52``!54T523D%-10``5$5-4$1)4@!435``+W1M<```
M979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF
M(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?
M<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C
M86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N
M<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD
M8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<
M,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM
M>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D
M8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O
M9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D
M<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H
M)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-
M04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C
M:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O
M9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.
M5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER
M(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ
M<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD
M.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@
M)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP
M("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI4
M96UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.
M3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*
M<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=
M.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP
M)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID
M;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P
M+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@
M,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R
M;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D[
M"GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I
M;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E
M;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]
M("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z
M)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG
M=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@
M+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H
M*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P
M87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!
M4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E
M8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![
M?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U
M=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@
M9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S
M="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&
M2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@
M;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B
M72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O
M<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D
M1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D
M(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<
M,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H
M92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE
M(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@
M+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%
M7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD[
M"F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B
M*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M
M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&
M2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*
M=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR
M96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M
M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N
M+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]
M*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H
M)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U
M9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H
M9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD
M+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U
M9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]
M("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65]
M(#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL
M:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N
M86UE(#T@7W-A=F5?87,H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*
M;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1-;V1U;&5#
M86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L
M"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M
M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U
M8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D
M;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD
M;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E
M7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF
M;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F
M24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F
M:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M
M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E
M96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`]
M(%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD
M:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W
M)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B
M.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE
M9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL
M92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP
M72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@
M+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E
M<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S
M("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+
M6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@
M<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]
M"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@
M(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N
M9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%0
M4%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y
M('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM
M<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*
M<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL
M7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6
M(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%
M3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N
M;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`
M05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI
M+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE
M;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@
M)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@
M>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I
M970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^
M/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A
M73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR
M97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD[
M"FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\
M.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P
M87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;
M17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A
M7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N
M=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,[
M"B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@
M*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P
M:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL
M92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I
M92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q
M("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)5
M3D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O
M=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@
M)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@
M>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*
M?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]
M"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z
M(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]
M"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@
M;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E
M(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P
M('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(*
M*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\
M9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]
M*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S
M("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1]
M.R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E
M;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D
M9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y
M+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@
M*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E
M<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[
M)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II
M9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q
M(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA
M;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D
M9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS
M<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@
M)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F
M*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*
M;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@
M/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD[
M"E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT
M96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K
M*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@
M07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL
M"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D
M(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II
M<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@
M;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R
M:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?
M;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D
M9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#([
M"B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE
M(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD
M8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG
M=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#
M04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO
M861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!
M1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I
M;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]
M"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N
M86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@
M24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D
M:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T
M0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A
M9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ
M<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L
M("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S
M*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C
M:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M
M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^
M9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_
M<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N
M9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X
M=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^
M8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M
M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D
M4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN
M8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS
M92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E
M<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D
M9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q
M<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B
M73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*
M?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*
M9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A
M<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G
M<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!
M4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E
M>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ
M)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D
M<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R
M<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U
M:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I
M8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#
M87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER
M92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P
M96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E
M($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E
M<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A
M='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I
M<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V
M86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@
M<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q
M=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![
M(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@
M)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@
M5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@
M>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@
M+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W
M=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F
M:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS
M,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E
M<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%
M4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D
M:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S
M97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7([
M"FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D
M(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O
M<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY
M("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E
M96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG
M=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE
M;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E
M:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T
M:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L
M("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A
M8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H
M(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM0
M05)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A
M8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0
M?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B
M(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?
M.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M
M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"([
M"FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP
M<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;
M17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@
M)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L
M("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F
M=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%
M3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H
M+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII
M9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM0
M05)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M
M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF
M("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y
M<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O
M9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M
M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U
M<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S
M97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%2
M7U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O
M7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D
M:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA
M;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M
M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P
M<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-
M17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2![
M"B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D
M<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*
M.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I
M(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN
M7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N
M=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T
M=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O
M<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-
M12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U0
M1$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%
M3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!
M3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM0
M05)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII
M9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R
M:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG
M.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I
M9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@
M<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A
M8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z
M.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R
M+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S
M=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64[
M"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2
M(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D
M.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,``$-!0TA%``````$;
M`SL```#8````&O__C,P```4H__^05````/3__Y$$```!,/__D4P```%<__^1
MU````8S__Y)D```!O/__D[P```'T__^4U````C#__Y<$```";/__ESP```*`
M__^7I````KS__YBD```"^/__F*P```,,__^:M````TC__YKL```#=/__G!P`
M``.T__^=3````]C__YV<```#_/__G<P```0<__^>?```!&C__Z/T```$N/__
MIC0```3L__^FG```!6S__[OL```%J/__O%P```7,__^]Q```!@@````4````
M``%Z4@`!>`X!&PP/H`$````````X````'/__CU@```"N`$:&#H<-B`R)"XH*
MBPF,"(T'C@:/!48.P`("@@K/SLW,R\K)R,?&#J`!0@L````H````6/__C\P`
M``!"`$:+"8P(C0>.!H\%1@[0`G3/SLW,RPZ@`0```````"P```"$__^/Z```
M`(8`1HD+B@J+"8P(C0>.!H\%1@[0`@)XS\[-S,O*R0Z@`0```"P```"T__^0
M0````)``1HH*BPF,"(T'C@:/!48.V`,"@L_.S<S+R@Z@`0```````#0```#D
M__^0H````50`1H<-B`R)"XH*BPF,"(T'C@:/!48.V`,#`4;/SLW,R\K)R,<.
MH`$`````.````1S__Y'````!&`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M""
M!`,!"L_.S<S+RLG(Q\8.H`$`````.````5C__Y*<```"+`!&A@Z'#8@,B0N*
M"HL)C`B-!XX&CP5&#M`"`P(>S\[-S,O*R<C'Q@Z@`0``````$````93__Y20
M````.``````````X```!J/__E+0```!B`$R&#H<-B`R)"XH*BPF,"(T'C@:/
M!48.R`("3L_.S<S+RLG(Q\8.H`$````````X```!Y/__E.````#^`$:&#H<-
MB`R)"XH*BPF,"(T'C@:/!48.T$("\,_.S<S+RLG(Q\8.H`$````````0```"
M(/__E:0````&`````````#@```(T__^5F````@(`1H8.APV(#(D+B@J+"8P(
MC0>.!H\%1@[@(P,!],_.S<S+RLG(Q\8.H`$``````"@```)P__^79````#0`
M2HL)C`B-!XX&CP5&#L`"7L_.S<S+#J`!````````/````IS__Y=P```!*@!&
MB@J+"8P(C0>.!H\%1@[((@+L"L_.S<S+R@Z@`4(+8@K/SLW,R\H.H`%&"P``
M`````"````+<__^88````2X`3(X&CP5&#L`"`O8*S\X.H`%&"P```"````,`
M__^9;````$X`3(X&CP5&#L`"<@K/S@Z@`4(+`````!P```,D__^9F````"P`
M1HX&CP5&#L`"7L_.#J`!````2````T3__YFH````K`!&A@Z'#8@,B0N*"HL)
MC`B-!XX&CP5*#L`";@K/SLW,R\K)R,?&#J`!1@L"9L_.S<S+RLG(Q\8.H`$`
M`````$P```.0__^:#```!7@`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[X!`)Z
M"L_.S<S+RLG(Q\8.H`%&"P,!N`K/SLW,R\K)R,?&#J`!0@L`````,````^#_
M_Y\T```"/`!,B`R)"XH*BPF,"(T'C@:/!6`.P`(#`@[/SLW,R\K)R`Z@`0``
M`#@```04__^A0````&@`1HH*BPF,"(T'C@:/!48.P`("3@K/SLW,R\H.H`%&
M"T;/SLW,R\H.H`$``````$````10__^'G````?H`1H8.APV(#(D+B@J+"8P(
MC0>.!H\%1@[8`@,!U@K/SLW,R\K)R,?&#J`!0@L`````````````.```!)3_
M_Z$H```53@!8A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M`'`Q4NS\[-S,O*R<C'
MQ@Z@`0``````(```!-#__[8\````;`!*C@:/!48.P`("6L_.#J`!````````
M.```!/3__[:(```!:`!,A@Z'#8@,B0N*"HL)C`B-!XX&CP5>#L`"`MH*S\[-
MS,O*R<C'Q@Z@`4(+````-```!3#__[>T```!%@!&B`R)"XH*BPF,"(T'C@:/
M!6X.P`("N`K/SLW,R\K)R`Z@`48+````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"'X````````(9```````````0````````+'````
M``````$````````"T@`````````/`````````_P`````````#````````!>0
M``````````T```````!0P``````````9````````J\@`````````&P``````
M```(`````````!H```````"KT``````````<``````````@`````;__^]0``
M``````(8``````````4````````+J``````````&`````````O``````````
M"@````````0:``````````L`````````&``````````5````````````````
M`````P```````*VX``````````(````````%*``````````4``````````<`
M````````%P```````!)H``````````<````````/R``````````(````````
M`J``````````"0`````````8`````````!@```````````````!O___[````
M``@```$`````;___^0`````````0````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````"KV``````````````````````````````7V@``
M`````!?Z````````&!H````````8.@```````!A:````````&'H````````8
MF@```````!BZ````````&-H````````8^@```````!D:````````&3H`````
M```96@```````!EZ````````&9H````````9N@```````!G:````````&?H`
M```````:&@```````!HZ````````&EH````````:>@```````!J:````````
M&KH````````:V@```````!KZ````````&QH````````;.@```````!M:````
M````&WH````````;F@```````!NZ````````&]H````````;^@```````!P:
M````````'#H````````<6@```````!QZ````````')H````````<N@``````
M`!S:````````'/H````````=&@```````!TZ````````'5H````````=>@``
M`````!V:````````';H````````=V@```````!WZ````````'AH````````>
M.@```````!Y:````````'GH````````>F@```````!ZP````````````````
M`````````````%#``````````````````````````````!>0````````````
M````````````````````````````````````````````````````````````
M`````````````````````+``"E!!4BYP;0H``````````````````%.F````
M````4-P``````````````````%'(````````4<P```````!3F@```````%$N
M````````4Z(``````````````````%.*````````4Y``````````````````
M`%.L1T-#.B`H06QP:6YE(#$R+C(N,5]G:70R,#(R,#DR-"UR,3`I(#$R+C(N
M,2`R,#(R,#DR-```+G-H<W1R=&%B`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS
M>6T`+F1Y;G-T<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF
M:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R
M87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM
M96YT````````````````````````````````````````````````````````
M```````````````````````````````````````````+`````0`````````"
M`````````@`````````"```````````8`````````````````````0``````
M````````$V____8``````````@````````(8`````````A@`````````V```
M``,```````````````@``````````````!T````+``````````(````````"
M\`````````+P````````"+@````$`````@`````````(`````````!@````E
M`````P`````````"````````"Z@````````+J`````````0:````````````
M`````````0``````````````+0````0``````````@````````_(````````
M#\@````````"H`````,```````````````@`````````&````#<````$````
M`````$(````````2:````````!)H````````!2@````#````$0`````````(
M`````````!@```!!`````0`````````&````````%Y`````````7D```````
M```<`````````````````````@``````````````/`````$`````````!@``
M`````!>L````````%ZP````````'``````````````````````0`````````
M(````$<````!``````````8````````>L````````!ZP````````,A``````
M```````````````(``````````````!-`````0`````````&````````4,``
M``````!0P``````````<`````````````````````@``````````````4P``
M``$``````````@```````%#<````````4-P```````!!!@``````````````
M``````(``````````````%L````!``````````(```````"1Y````````)'D
M`````````-P````````````````````$``````````````!I`````0``````
M```"````````DL````````"2P`````````5H````````````````````"```
M````````````<P````X``````````P```````*O(````````F\@`````````
M"`````````````````````@`````````"````'\````/``````````,`````
M``"KT````````)O0``````````@````````````````````(``````````@`
M``"+````!@`````````#````````J]@```````";V`````````'@````!```
M````````````"``````````0````E`````$``````````P```````*VX````
M````G;@````````"2`````````````````````@`````````"````)D````!
M``````````,```````"P`````````*```````````(``````````````````
M```(``````````````"?````"``````````#````````L(````````"@@```
M``````!8````````````````````"```````````````I`````$`````````
M,```````````````````H(``````````-0````````````````````$`````
M`````0````$````#`````````````````````````````*"U`````````*T`
7```````````````````!````````````
